@@ -78,6 +78,8 @@ DEVICE_EXTRACTOR = re.compile(r'^(?:(.*\d)p|(.*\D))(?:\d+)$')
 PARTED_TABLE_TYPE_REGEX = re.compile(r'^.*partition\s+table\s*:\s*(gpt|msdos)',
                                      re.IGNORECASE)
 
+_EARLY_LOG_BUFFER = []
+
 
 def execute(*cmd, **kwargs):
     """Convenience wrapper around ironic_lib's execute() method.
@@ -187,7 +189,16 @@ def _get_vmedia_params():
 
 def _early_log(msg, *args):
     """Log via printing (before oslo.log is configured)."""
-    print('ironic-python-agent:', msg % args, file=sys.stderr)
+    log_entry = msg % args
+    _EARLY_LOG_BUFFER.append(log_entry)
+    print('ironic-python-agent:', log_entry, file=sys.stderr)
+
+
+def log_early_log_to_logger():
+    """Logs early logging events to the configured logger."""
+
+    for entry in _EARLY_LOG_BUFFER:
+        LOG.info("Early logging: %s", entry)
 
 
 def _copy_config_from(path):
@@ -467,7 +478,6 @@ def get_command_output(command):
     except (processutils.ProcessExecutionError, OSError) as e:
         error_msg = ('Failed to get the output of the command "%(command)s". '
                      'Error: %(error)s' % {'command': command, 'error': e})
-        LOG.error(error_msg)
         raise errors.CommandExecutionError(error_msg)
     return io.BytesIO(out)
 
@@ -536,7 +546,7 @@ def collect_system_logs(journald_max_lines=None):
         try:
             io_dict[file_name] = get_command_output(command)
         except errors.CommandExecutionError:
-            pass
+            LOG.debug('Collecting logs from command %s has failed', command)
 
     io_dict = {}
     file_list = []
@@ -825,21 +835,11 @@ def sync_clock(ignore_errors=False):
                 raise errors.CommandExecutionError(msg)
     elif method == 'chronyd':
         try:
-            # 0 should be if chronyd started
-            # 1 if already running
-            execute('chronyd', check_exit_code=[0, 1])
-            # NOTE(TheJulia): Once started, chronyd forks and stays in the
-            # background as a server service, it will continue to keep the
-            # clock in sync.
-            try:
-                execute('chronyc', 'add', 'server', CONF.ntp_server)
-            except processutils.ProcessExecutionError as e:
-                if 'Source already present' not in str(e):
-                    msg = 'Error occured adding ntp server: %s' % e
-                    LOG.error(msg)
-                    raise errors.CommandExecutionError(msg)
-            # Force the clock to sync now.
-            execute('chronyc', 'makestep')
+            # stop chronyd, ignore if it ran before or not
+            execute('chronyc', 'shutdown', check_exit_code=[0, 1])
+            # force a time sync now
+            query = "server " + CONF.ntp_server + " iburst"
+            execute("chronyd -q \'%s\'" % query, shell=True)
             LOG.debug('Set software clock using chrony')
         except (processutils.ProcessExecutionError,
                 errors.CommandExecutionError) as e:
